==> crossfire-0.92.0.tar.gz: crossfire-0.92.0/crossedit/Crossedit.ad.h <==
"*mapWidth:	15",
"*mapHeight:	15",
"*creator:	Gnat the Gnu",
"*email:		gnu@foo.bar",
"*cmdCrossfire:	crossfire -pix",
"*cmdReset:	crossclient -cmd 'dm dm;reset %s'",
"*cmdGoto:	crossclient -cmd 'dm dm;goto %s'",
"Crossedit*font: -*-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"Crossedit*Text*font: *-lucidatypewriter-medium-r-normal-*-12-*-*-*-*-*-*-*",
"*title:			CrossEdit",
"*iconName:		CrossEdit",
"*new.label:		New",
"*open.label:		Open",
"*crossfire.label:	CrossFire",
"*quit.label:		Quit",
"*refresh.label:		Refresh",
"*cancel.label:		Cancel",
"*apply.label:		Apply",
"*ok.label:		OK",
"*mapFileButton.label:	File",
"*mapEditButton.label:	Edit",
"*mapOptionButton.label:	Options",
"*editButton.label:	Edit",
"*fileButton.label:	File",
"*infoButton.label:	Info",
"*archButton.label:	Arch",
"*pickButton.label:	Pick",
"*wallButton.label:	Walls",
"*save.label:		Save",
"*saveAs.label:		Save as",
"*load.label:		Load",
"*reload.label:		Reload",
"*clear.label:		Clear",
"*enter.label:		Enter",
"*reset.label:		Reset",
"*close.label:		Close",
"*readOnly.label:	Read only",
"*overWrite.label:	Overwrite",
"*autoChoose.label:	Choose",
"*sparse.label:		Stacking",
"*attributes.label:	Attributes",
"*cut.label:		Cut",
"*copy.label:		Copy",
"*paste.label:		Paste",
"*fill.label:		Fill",
"*wipe.label:		Wipe",
"*box.label:		Box",
"*vars.label:		Variable",
"*exact.label:		Dump",
"Crossedit*background:		DarkSeaGreen",
"Crossedit*foreground:		Black",
"Crossedit*SimpleMenu*background:ForestGreen",
"Crossedit*SimpleMenu*foreground:White",
"Crossedit*Command*background:	ForestGreen",
"Crossedit*Command*foreground:	White",
"Crossedit*Toggle*background:	ForestGreen",
"Crossedit*Toggle*foreground:	White",
"Crossedit*MenuButton*background:ForestGreen",
"Crossedit*MenuButton*foreground:White",
"Crossedit*Label*background:	ForestGreen",
"Crossedit*Label*foreground:	White",
"Crossedit*CrEdit*background:	gray60",
"Crossedit*CrList*background:	DarkSeaGreen",
"Crossedit*CrFace*background:	DarkSeaGreen",
"*box.min: 28",
"*box.max: 28",
"*SimpleMenu*HorizontalMargins: 16",
"*view.allowVert:	True",
"*view.forceBars:	True",
"*view.width:		140",
"*info.width:		140",
"*view.height:		72",
"*arch.allowVert:	True",
"*arch.forceBars:	True",
"*arch.height:		300",
"*item.width:		140",
"*item.height:		48",
"*item.max:		84",
"*item.min:		84",
"*item.name.width:	136",
"*item.name.label:	NotSelected",
"*item.face.width:	136",
"*pane.info.showGrip:	false",
"*pane.box.showGrip:	false",
"*pane.arch.showGrip:	false",
"*edit*allowResize: True",
"*edit*allowShellResize: False",
"*edit*view.allowHoriz: True",
"*edit*view.allowVert: True",
"*edit*vbox.orientation: vertical",
"*edit*hbox.orientation: horizontal",
"*edit*view.forceBars: True",
"*edit*view.horizontal.translations: #override \
  <Key>Right : StartScroll(Forward) NotifyScroll(Proportional) EndScroll() \\n\
  <Key>Left: StartScroll(Backward) NotifyScroll(Proportional) EndScroll() \\n",
"*edit*view.vertical.translations: #override \
  <Key>Down: StartScroll(Forward) NotifyScroll(Proportional) EndScroll() \\n\
  <Key>Up: StartScroll(Backward) NotifyScroll(Proportional) EndScroll() \\n",
"*attr*name.width: 300",
"*attr*name.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*attr*Box.borderWidth: 0",
"*attr*view.width: 300",
"*attr*view.height: 100",
"*attr*view*label.width: 60",
"*attr*view*value.width: 208",
"*attr*view*value.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*attr*view*toggle.width: 90",
"*attr*view*Box.hSpace: 3",
"*attr*view*Box.vSpace: 1",
"*attr*face.width: 96",
"*attr*face.height: 48",
"*attr*msg.width:  300",
"*attr*msg.height: 76",
"*attr*msg.autoFill: True",
"*attr*msg.scrollVertical: always",
"*attr*inventory.width: 198",
"*attr*inventory.height: 72",
"*attr*inventory.allowVert: True",
"*attr*inventory.forceBars: True",
"*attr*exact.width: 96",
"*attr*vars.width: 60",
"*attr*var.width: 234",
"*attr*var.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*attr*value.width: 136",
"*attr*ok.width: 96",
"*attr*apply.width: 96",
"*attr*cancel.width: 96",
"*mapattr*name.width: 300",
"*mapattr*name.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*mapattr*Box.borderWidth: 0",
"*mapattr*view.width: 300",
"*mapattr*view.height: 220",
"*mapattr*view*label.width: 70",
"*mapattr*view*value.width: 198",
"*mapattr*view*value.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*mapattr*view*Box.hSpace: 3",
"*mapattr*view*Box.vSpace: 1",
"*mapattr*face.width: 96",
"*mapattr*face.height: 24",
"*mapattr*msg.width:  300",
"*mapattr*msg.height: 76",
"*mapattr*msg.autoFill: True",
"*mapattr*msg.scrollVertical: always",
"*mapattr*inventory.width: 198",
"*mapattr*inventory.height: 24",
"*mapattr*inventory.allowVert: True",
"*mapattr*inventory.forceBars: True",
"*mapattr*exact.width: 96",
"*mapattr*vars.width: 60",
"*mapattr*var.width: 234",
"*mapattr*var.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*mapattr*ok.width: 96",
"*mapattr*apply.width: 96",
"*mapattr*cancel.width: 96",
"*infoFile.title:		Documentation",
"*infoFile*text.width:		600",
"*infoFile*text.height:		330",
"*infoFile*cancel.width: 	100",
"*infoFile*cancel.label:		Dismiss",
"*infoFile*file.width:		290",
"*infoFile*Paned.showGrip:	False",
"*infoFile*text.scrollHorizontal:whenNeeded",
"*infoFile*text.scrollVertical:	always",
"*infoFile*Text.width:		450",
"*infoFile*Text.height:		300",
"*infoFile*Text.scrollHorizontal:never",
"*infoFile*Text.scrollVertical:	always",
"*fileSelect.title: File Select",
"*fileSelect*Viewport.allowVert: True",
"*fileSelect*Viewport.forceBars: True",
"*fileSelect*dirList.defaultColumns: 1",
"*fileSelect*dirList.forceColumns: True",
"*fileSelect*dirView.width: 100 ",
"*fileSelect*dirView.height: 250 ",
"*fileSelect*fileList.defaultColumns: 3",
"*fileSelect*fileList.forceColumns: False",
"*fileSelect*fileList.Longest: 100",
"*fileSelect*fileList.translations: #override \
  <Btn1Down>:    Set() Notify() \\n\
  <Btn1Up>(2): Set() Notify() CnvPathReturn() \\n",
"*fileSelect*fileView.width: 300 ",
"*fileSelect*fileView.height: 250 ",
"*fileSelect*cwd.width: 300",
"*fileSelect*cwd.resize: False",
"*fileSelect*cwd.justify: left",
"*fileSelect*cancel.width: 100",
"*fileSelect*ok.width: 300",
"*fileSelect*text.width: 100",
"*fileSelect.height: 400",
"*fileSelect*text.translations: #override \
  <Key>Tab:    Nop() \\n\
  <Key>Return: CnvPathReturn() \\n",
"*dump.title:			Object Dump",
"*dump*text.width:		150",
"*dump*text.height:		400",
"*dump*text.scrollHorizontal:	newer",
"*dump*text.scrollVertical:	always",
"*dump*cancel.width:		150",
"*dump*cancel.label:		Dismiss",
"*vars.title:		Select variable",
"*vars*view.width:	300",
"*vars*view.height:	250",
"*vars*view.allowVert:	True",
"*vars*view.forceBars:	True",
"*vars*cancel.width:	300",

==> crossfire_1.6.0.dfsg.1.orig.tar.gz: crossfire-1.6.0.orig/crossedit/Crossedit.ad.h <==
"*mapWidth:	15",
"*mapHeight:	15",
"*creator:	Gnat the Gnu",
"*email:		gnu@foo.bar",
"*cmdCrossfire:	crossfire -pix",
"*cmdReset:	crossclient -cmd 'dm dm;reset %s'",
"*cmdGoto:	crossclient -cmd 'dm dm;goto %s'",
"Crossedit*font: -*-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"Crossedit*Text*font: *-lucidatypewriter-medium-r-normal-*-12-*-*-*-*-*-*-*",
"*title:			CrossEdit",
"*iconName:		CrossEdit",
"*new.label:		New",
"*open.label:		Open",
"*crossfire.label:	CrossFire",
"*quit.label:		Quit",
"*refresh.label:		Refresh",
"*cancel.label:		Cancel",
"*apply.label:		Apply",
"*ok.label:		OK",
"*mapFileButton.label:	File",
"*mapEditButton.label:	Edit",
"*mapOptionButton.label:	Options",
"*editButton.label:	Edit",
"*fileButton.label:	File",
"*infoButton.label:	Info",
"*archButton.label:	Arch",
"*pickButton.label:	Pick",
"*wallButton.label:	Walls",
"*save.label:		Save",
"*saveAs.label:		Save as",
"*load.label:		Load",
"*reload.label:		Reload",
"*clear.label:		Clear",
"*enter.label:		Enter",
"*reset.label:		Reset",
"*close.label:		Close",
"*readOnly.label:	Read only",
"*overWrite.label:	Overwrite",
"*autoChoose.label:	Choose",
"*sparse.label:		Stacking",
"*attributes.label:	Attributes",
"*cut.label:		Cut",
"*copy.label:		Copy",
"*paste.label:		Paste",
"*fill.label:		Fill",
"*fillbelow.label:	Fill Below",
"*wipe.label:		Wipe",
"*wipebelow.label:	Wipe Below",
"*box.label:		Box",
"*vars.label:		Variable",
"*exact.label:		Dump",
"Crossedit*background:		DarkSeaGreen",
"Crossedit*foreground:		Black",
"Crossedit*SimpleMenu*background:ForestGreen",
"Crossedit*SimpleMenu*foreground:White",
"Crossedit*Command*background:	ForestGreen",
"Crossedit*Command*foreground:	White",
"Crossedit*Toggle*background:	ForestGreen",
"Crossedit*Toggle*foreground:	White",
"Crossedit*MenuButton*background:ForestGreen",
"Crossedit*MenuButton*foreground:White",
"Crossedit*Label*background:	ForestGreen",
"Crossedit*Label*foreground:	White",
"Crossedit*CrEdit*background:	gray60",
"Crossedit*CrList*background:	DarkSeaGreen",
"Crossedit*CrFace*background:	DarkSeaGreen",
"*box.min: 28",
"*box.max: 28",
"*SimpleMenu*HorizontalMargins: 16",
"*view.allowVert:	True",
"*view.forceBars:	True",
"*view.width:		140",
"*info.width:		140",
"*view.height:		72",
"*arch.allowVert:	True",
"*arch.forceBars:	True",
"*arch.height:		300",
"*item.width:		140",
"*item.height:		48",
"*item.max:		84",
"*item.min:		84",
"*item.name.width:	136",
"*item.name.label:	NotSelected",
"*item.face.width:	136",
"*pane.info.showGrip:	false",
"*pane.box.showGrip:	false",
"*pane.arch.showGrip:	false",
"*edit*allowResize: True",
"*edit*allowShellResize: False",
"*edit*view.allowHoriz: True",
"*edit*view.allowVert: True",
"*edit*vbox.orientation: vertical",
"*edit*hbox.orientation: horizontal",
"*edit*view.forceBars: True",
"*edit*view.horizontal.translations: #override \
  <Key>Right : StartScroll(Forward) NotifyScroll(Proportional) EndScroll() \\n\
  <Key>Left: StartScroll(Backward) NotifyScroll(Proportional) EndScroll() \\n",
"*edit*view.vertical.translations: #override \
  <Key>Down: StartScroll(Forward) NotifyScroll(Proportional) EndScroll() \\n\
  <Key>Up: StartScroll(Backward) NotifyScroll(Proportional) EndScroll() \\n",
"*attr*name.width: 300",
"*attr*name.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*attr*Box.borderWidth: 0",
"*attr*view.width: 300",
"*attr*view.height: 100",
"*attr*view*label.width: 60",
"*attr*view*value.width: 208",
"*attr*view*value.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*attr*view*toggle.width: 90",
"*attr*view*Box.hSpace: 3",
"*attr*view*Box.vSpace: 1",
"*attr*face.width: 96",
"*attr*face.height: 48",
"*attr*msg.width:  300",
"*attr*msg.height: 76",
"*attr*msg.autoFill: True",
"*attr*msg.scrollVertical: always",
"*attr*inventory.width: 198",
"*attr*inventory.height: 72",
"*attr*inventory.allowVert: True",
"*attr*inventory.forceBars: True",
"*attr*exact.width: 96",
"*attr*vars.width: 60",
"*attr*var.width: 234",
"*attr*var.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*attr*value.width: 136",
"*attr*ok.width: 96",
"*attr*apply.width: 96",
"*attr*cancel.width: 96",
"*mapattr*name.width: 300",
"*mapattr*name.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*mapattr*Box.borderWidth: 0",
"*mapattr*view.width: 300",
"*mapattr*view.height: 220",
"*mapattr*view*label.width: 70",
"*mapattr*view*value.width: 198",
"*mapattr*view*value.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*mapattr*view*Box.hSpace: 3",
"*mapattr*view*Box.vSpace: 1",
"*mapattr*face.width: 96",
"*mapattr*face.height: 24",
"*mapattr*msg.width:  300",
"*mapattr*msg.height: 76",
"*mapattr*msg.autoFill: True",
"*mapattr*msg.scrollVertical: always",
"*mapattr*inventory.width: 198",
"*mapattr*inventory.height: 24",
"*mapattr*inventory.allowVert: True",
"*mapattr*inventory.forceBars: True",
"*mapattr*exact.width: 96",
"*mapattr*vars.width: 60",
"*mapattr*var.width: 234",
"*mapattr*var.translations: #override \
  <Key>Return: beginning-of-line()\\n",
"*mapattr*ok.width: 96",
"*mapattr*apply.width: 96",
"*mapattr*cancel.width: 96",
"*infoFile.title:		Documentation",
"*infoFile*text.width:		600",
"*infoFile*text.height:		330",
"*infoFile*cancel.width: 	100",
"*infoFile*cancel.label:		Dismiss",
"*infoFile*file.width:		290",
"*infoFile*Paned.showGrip:	False",
"*infoFile*text.scrollHorizontal:whenNeeded",
"*infoFile*text.scrollVertical:	always",
"*infoFile*Text.width:		450",
"*infoFile*Text.height:		300",
"*infoFile*Text.scrollHorizontal:never",
"*infoFile*Text.scrollVertical:	always",
"*fileSelect.title: File Select",
"*fileSelect*Viewport.allowVert: True",
"*fileSelect*Viewport.forceBars: True",
"*fileSelect*dirList.defaultColumns: 1",
"*fileSelect*dirList.forceColumns: True",
"*fileSelect*dirView.width: 100 ",
"*fileSelect*dirView.height: 250 ",
"*fileSelect*fileList.defaultColumns: 3",
"*fileSelect*fileList.forceColumns: False",
"*fileSelect*fileList.Longest: 100",
"*fileSelect*fileList.translations: #override \
  <Btn1Down>:    Set() Notify() \\n\
  <Btn1Up>(2): Set() Notify() PathReturn() \\n",
"*fileSelect*fileView.width: 300 ",
"*fileSelect*fileView.height: 250 ",
"*fileSelect*cwd.width: 300",
"*fileSelect*cwd.resize: False",
"*fileSelect*cwd.justify: left",
"*fileSelect*cancel.width: 100",
"*fileSelect*ok.width: 300",
"*fileSelect*text.width: 100",
"*fileSelect.height: 400",
"*fileSelect*text.translations: #override \
  <Key>Tab:    Nop() \\n\
  <Key>Return: PathReturn() \\n",
"*dump.title:			Object Dump",
"*dump*text.width:		150",
"*dump*text.height:		400",
"*dump*text.scrollHorizontal:	newer",
"*dump*text.scrollVertical:	always",
"*dump*cancel.width:		150",
"*dump*cancel.label:		Dismiss",
"*vars.title:		Select variable",
"*vars*view.width:	300",
"*vars*view.height:	250",
"*vars*view.allowVert:	True",
"*vars*view.forceBars:	True",
"*vars*cancel.width:	300",
